@@ -43,7 +43,7 @@ def test_do_cleanup(oebuild_repo_init_object):
 """ Test map for validation of all api arguments. can add or delete ..depending upon use case"""
 test_map = {
     "envsetup": [None, 1],
-    "target": [None, 1],
+    "targets": [None, 1],
     "distro": [1],
     "repo": [
         {"url": "", "branch": "main", "manifest": "default.xml"},
