@@ -70,4 +70,9 @@ def setup_parser() -> argparse.ArgumentParser:
         help="Path to a local manifest file which will be used to override repo setup before doing repo sync. This input is ignored if sources used is git_trees in the build definition",
         default=None,
     )
+    group.add_argument(
+        "--publish-artifacts",
+        help="Directory where artifacts will be copied. It defaults to output",
+        default=None,
+    )
     return parser
