@@ -6,10 +6,7 @@ from dataclasses import asdict, dataclass, field, fields
 from typing import Dict, List
 from tuxmake.runtime import Runtime
 from tuxmake.logging import set_debug, debug
-from tuxbake.utils import (
-    repo_init,
-    git_init,
-)
+from tuxbake.utils import repo_init, git_init, copy_artifacts
 from pathlib import Path
 from tuxbake.exceptions import TuxbakeParsingError
 from tuxbake.helper import *
@@ -64,7 +61,8 @@ class OEBuild(Base):
     local_manifest: str = None
     pinned_manifest: str = None
     # For future use
-    artifacts: str = None
+    artifacts: List[str] = None
+    artifacts_dir: str = None
 
     @dataclass
     class Repo:
@@ -78,6 +76,7 @@ class OEBuild(Base):
         branch: str = None
         ref: str = None
         sha: str = None
+        dest: str = None
 
     def __post_init__(self):
         self.log_dir = self.src_dir
@@ -169,6 +168,7 @@ class OEBuild(Base):
                 branch = git_obj.get("branch", "")
                 ref = git_obj.get("ref", "")
                 sha = git_obj.get("sha", "")
+                dest = git_obj.get("dest", "")
                 # validations
                 validate_git_repo(url)
                 if branch:
@@ -181,6 +181,8 @@ class OEBuild(Base):
                     validate_git_ref(ref)
                 if sha:
                     validate_git_sha(sha)
+                if dest:
+                    validate_git_dest(dest)
         else:
             raise (TuxbakeParsingError("repo or git_trees must be specified!!"))
 
@@ -258,6 +260,8 @@ class OEBuild(Base):
                 str,
                 f"Unexpected argument for dl_dir, expected string: '{oebuild_data['dl_dir']}'",
             )
+        if oebuild_data.get("artifacts"):
+            validate_artifacts(oebuild_data["artifacts"])
 
     def __prepare__(self):
         os.makedirs(self.src_dir, exist_ok=True)
@@ -279,7 +283,11 @@ class OEBuild(Base):
         self._runtime = Runtime.get(self.runtime)
         if self.sync_only:
             return
-        self._runtime.source_dir = Path(self.src_dir)
+        if self.distro.startswith("openbmc"):
+            self._runtime.source_dir = Path(f"{self.src_dir}/openbmc")
+            self.envsetup = f"{self.envsetup} {self.machine}"
+        else:
+            self._runtime.source_dir = Path(self.src_dir)
         self._runtime.set_user("tuxbake")
         self._runtime.set_group("tuxbake")
         self._runtime.basename = "build"
@@ -329,7 +337,7 @@ class OEBuild(Base):
         cmd = [
             "bash",
             "-c",
-            f"rm {self.build_dir}/conf/bblayers.conf; rm {self.build_dir}/conf/local.conf; source {self.envsetup} {self.build_dir}; cat ../extra_local.conf >> conf/local.conf; cat ../bblayers.conf >> conf/bblayers.conf || true; echo 'Dumping local.conf..'; cat conf/local.conf; bitbake -e > bitbake-environment;",
+            f"rm -f {self.build_dir}/conf/bblayers.conf && rm -f {self.build_dir}/conf/local.conf && source {self.envsetup} {self.build_dir} && cat ../extra_local.conf >> conf/local.conf && cat ../bblayers.conf >> conf/bblayers.conf || true && echo 'Dumping local.conf..' && cat conf/local.conf && bitbake -e |tee bitbake-environment",
         ]
         if self._runtime.run_cmd(cmd, offline=False):
             self.result = "pass"
@@ -349,6 +357,10 @@ class OEBuild(Base):
                 self.result = "fail"
                 return
 
+    def publish_artifacts(self):
+        artifacts_dir = f"{self.src_dir}/{self.artifacts_dir}"
+        copy_artifacts(self.artifacts, self.src_dir, artifacts_dir)
+
     def do_cleanup(self):
         if self._runtime:
             self._runtime.cleanup()
